@@ -59,7 +59,6 @@ OfflineMode=False
 PreviousMode="normal"
 SilentProfile=False
 PreviouseProfile="silent"
-#OldOfflineMode="False" #restore original state after recording
 DelayStart=0
 interval=0
 GraphStart=0
@@ -76,6 +75,8 @@ AlarmID=-1 #cookie for communication to system
 #EventSetAlarm=-1
 #EventEffectiveAlarm=-1
 
+StopAfterAlarm=True
+
 #arrays, indexes, lenghts
 #arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
 #arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
