@@ -23,14 +23,14 @@ from functions_general import *
 def ReadAccSensor():    
     coords=[0, 0]    
     if(data.demo==False):        
-        for i in range(data.sample_smoothing):
+        for i in range(data.Sample_smoothing):
             f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
             coords_tmp = [int(w) for w in f.readline().split()]
             f.close()
             coords[0]=coords[0] + coords_tmp[0] #X
             coords[1]=coords[1] + coords_tmp[1] #Y
-        coords[0]=coords[0] / data.sample_smoothing
-        coords[1]=coords[1] / data.sample_smoothing
+        coords[0]=coords[0] / data.Sample_smoothing
+        coords[1]=coords[1] / data.Sample_smoothing
     else:
         coords[0]=int(random.uniform(-50,50))
         coords[1]=int(random.uniform(-50,50))
@@ -103,7 +103,8 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
             Xder=0
             Yder=0
             XYder=0
-        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+#        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+        records.arrData[3][i]=XYder
         records.arrData[4][i]=lastindexovertrigger
 #        if(records.arrData[3][i]>data.Trigger): #over trigger
 #            lastindexovertrigger=i
@@ -304,8 +305,9 @@ def showGraph(self,  QtGui):
             if(records.arrData[3][p+j]>peak): peak=records.arrData[3][p+j]
         x=i/Xscale
 #        x=i/Xscale+1
-        paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
-        
+#        paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
+        h=min(peak*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+        paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
         
         if(peak>data.Trigger):
             paint.setPen(QtGui.QColor("black"))
