@@ -164,9 +164,16 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
             QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity (24h)!\nThe recording stops now.", QtGui.QMessageBox.Ok)
-            RecordWindow.StopMeasurement()
-    RecordWindow.UpdateScreen()        
-
+#            RecordWindow.StopMeasurement()
+            StopMeasurement() #but keep alarm active!
+    RecordWindow.UpdateScreen()      
+  
+#    print data.AlarmIsActive,  data.StopAfterAlarm
+    if(data.AlarmIsActive==True):
+#        print "Alarm is active"
+        if(data.StopAfterAlarm==True):
+#            print "Stop measurement, alarm is active"
+            StopMeasurement() #but keep alarm active!
   
 
 
@@ -183,8 +190,8 @@ def InitMeasurement():
 
     records.User=data.user
     records.SWversion=data.version
-    records.Sampling_interval=data.Sampling_interval #todo: change names to new system
-    records.Sample_smoothing=data.sample_smoothing
+    records.Sampling_interval=data.Sampling_interval
+    records.Sample_smoothing=data.Sample_smoothing
     records.Value_smoothing=data.Value_smoothing
     records.Trigger=data.Trigger #save Trigger level on start
     records.statusID="OK"
@@ -201,7 +208,7 @@ def InitMeasurement():
     
     #change to offline mode and silent profile if requested
     if(data.QuickMode==False):
-        if(data.OfflineMode=="True"): #change to offline mode
+        if(data.OfflineMode==True): #change to offline mode
             try:
                 cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
                 ret=os.popen2(cmd) #get current mode
@@ -215,7 +222,7 @@ def InitMeasurement():
             except:
                 pass
                 
-        if(data.SilentProfile=="True"): #change to silent profile
+        if(data.SilentProfile==True): #change to silent profile
             try:
                 cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
                 ret=os.popen2(cmd) #get current profile
@@ -253,7 +260,7 @@ def InitMeasurement():
     if(data.debug==1): 
         print "Start timers (Interval:", data.interval ,"ms)..."
         print "Sampling interval:", data.interval, "ms"
-        print "sample_smoothing:", data.sample_smoothing, "x"
+        print "sample_smoothing:", data.Sample_smoothing, "x"
         print "value_smoothing:", data.Value_smoothing, "x"
         print "=> log interval:", data.interval*data.Value_smoothing, "ms"
         print "Derivation:", data.Derivation, "(substracts value", data.Derivation, "- value 0)"  
@@ -269,9 +276,13 @@ def InitMeasurement():
 def StopMeasurement():
     global app
     
-    DeleteAlarm() #delete Alarm if existing
+    RecordWindow.UpdateScreenStop()
     
+#    DeleteAlarm() #delete Alarm if existing
+    
+#    print "Stop Measurement",  data.run    
     if(data.run==True): #in recording
+        if(data.debug==1): print "Stop Timer"
         app.timer_GetData.stop()
         StopLogfile() 
         UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
@@ -280,14 +291,14 @@ def StopMeasurement():
 
     #change back to nromal mode and general profile if requested
     if(data.QuickMode==False): #normal mode
-        if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
+        if(data.OfflineMode==True and data.demo!=1): #change to offline mode
             try:
                 if(data.PreviousMode=="normal"): #was normal (before start measurement), so restore to normal
                     cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
                     os.popen(cmd)
             except:
                 pass
-        if(data.SilentProfile=="True" and data.demo!=1): #change to offline mode
+        if(data.SilentProfile==True and data.demo!=1): #change to offline mode
             try:
                 if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
                     cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
@@ -554,16 +565,15 @@ class frmRecordWindow(QMainWindow):
         
         
         
-        
-        
     def UpdateScreen(self):
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-#            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
-            d=time.strftime("%X", time.gmtime(time_difference))
+#            d=time.strftime("%X", time.gmtime(time_difference))
+            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
             self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
-        
+        else: self.UpdateScreenStop()
+            
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
@@ -573,9 +583,25 @@ class frmRecordWindow(QMainWindow):
         else: self.ui.bRaiseTrigger.setEnabled(True)
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
+        
 
 
         
+    
+
+    def UpdateScreenStop(self):
+        self.ui.bStop.setText("Close")
+        t=time.mktime(time.localtime())
+        time_difference=t-data.StartTimeSec
+#        d=time.strftime("%X", time.gmtime(time_difference))
+        d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
+        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries, stopped)")
+        
+        
+        
+        
+        
+        
     def StopMeasurement(self):
             self.closeEvent(0)
 
@@ -725,7 +751,8 @@ class frmViewWindow(QMainWindow):
 #        diff_tuple=Seconds2Tuple(diff_sec)
 #        print diff_tuple,  records.StartTime_tuple,  EndTime_tuple
 #        diff=strftime("%H:%M:%S", diff_tuple)
-        diff=time.strftime("%X", time.gmtime(diff_sec))
+#        diff=time.strftime("%X", time.gmtime(diff_sec))
+        diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
         if(diff_sec>86400): d="1 day, " #longer than 24h
         else: d=""
         self.ui.lblTimes.setText(str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
@@ -1016,10 +1043,12 @@ class frmConfigWindow(QMainWindow):
     ## 
     ###########################################################################
     def UpdateScreen(self):
-        if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
+        if(data.OfflineMode==True): self.ui.cOfflineMode.setChecked(True)
         else: self.ui.cOfflineMode.setChecked(False)    
-        if(data.SilentProfile=="True"): self.ui.cSilentProfile.setChecked(True)
-        else: self.ui.cSilentProfile.setChecked(False)        
+        if(data.SilentProfile==True): self.ui.cSilentProfile.setChecked(True)
+        else: self.ui.cSilentProfile.setChecked(False)      
+        if(data.StopAfterAlarm==True): self.ui.cStopAfterAlarm.setChecked(True)
+        else: self.ui.cStopAfterAlarm.setChecked(False)        
         self.ui.lblUserName.setText(data.user)
         self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
@@ -1030,17 +1059,23 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def closeEvent(self, event):        
         if(self.ui.cOfflineMode.isChecked()==True):          
-                data.OfflineMode="True"
+                data.OfflineMode=True
         else: 
-            data.OfflineMode="False"
+            data.OfflineMode=False
         config.set('main', 'OfflineMode', str(data.OfflineMode))   
         
         if(self.ui.cSilentProfile.isChecked()==True):          
-                data.SilentProfile="True"
+                data.SilentProfile=True
         else: 
-            data.SilentProfile="False"
+            data.SilentProfile=False
         config.set('main', 'SilentProfile', str(data.SilentProfile))   
         
+        if(self.ui.cStopAfterAlarm.isChecked()==True):          
+                data.StopAfterAlarm=True
+        else: 
+            data.StopAfterAlarm=False
+        config.set('main', 'StopAfterAlarm', str(data.StopAfterAlarm))   
+        
         config.set('main', 'user', str(data.user.encode( "utf-8" )))      
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
         
@@ -1157,7 +1192,8 @@ class frmAdditionalInfoWindow(QMainWindow):
             d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
         
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
-        diff=time.strftime("%X", time.gmtime(diff_sec))
+#        diff=time.strftime("%X", time.gmtime(diff_sec))
+        diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
         
         if(diff_sec>86400): diff="1 day, "+diff #longer than 24h
         
@@ -1370,8 +1406,8 @@ class frmAskForKeepWindow(QMainWindow):
     def RemoveRecord(self): #removed record
         print "Stop recording and remove record"
         global StartWindow,  RecordWindow
-        DeleteAlarm() #delete Alarm if existing
         StopMeasurement()
+        DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
         print "Delete logfile: "+data.logfilename
         os.remove(data.logfolder+data.logfilename)
